# Changelog

All notable changes to this project will be documented in this file.

## [0.1.6] - 2025-03-28

### Added
- Changes in GRPC.md
- Changes in grpc-scan.py
- Changes in tests/test_simple.py

## [0.1.5] - 2025-03-28

### Added
- Changes in src/apifunc/cli.py
- Changes in src/apifunc/new.py

## [0.1.4] - 2025-03-28

## [0.1.3] - 2025-03-28

## [0.1.2] - 2025-03-28

### Added
- Changes in setup.cfg
- Changes in setup.py
- Changes in src/apifunc/__init__.py
- Changes in src/apifunc/_version.py
- Changes in src/apifunc/apifunc.py

## [0.1.2] - 2025-03-28

### Added
- Changes in CNAME
- Changes in apifunc.py
- Changes in changelog.py
- Changes in git.sh
- Changes in publish.sh
- Changes in requirements-dev.txt
- Changes in requirements.txt
- Changes in version.sh

